@@ -26,3 +26,9 @@ def get_document_title(docname, doctree):
         return title.astext()
     else:
         raise Exception(f'{docname}: first <section> has no <title>')
+
+def make_reference(text, from_docname, to_docname, app):
+    ref = nodes.reference()
+    ref['refuri'] = app.builder.get_relative_uri(from_=from_docname, to=to_docname)
+    ref += nodes.Text(text)
+    return ref
